==> realestate-supervise-common-1.0.0-20190527.033121-2-sources.jar: cn/gtmap/realestate/supervise/entity/XtLog.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author hqz
 * @version 1.0, 2017/7/10
 * @description 系统日志表
 */
@Table(name = "XT_LOG")
public class XtLog {

    /**
     * 日志编码
     */
    @Id
    private String logId;

    /**
     * 日志参数
     */
    private String logArgs;

    /**
     * 日志信息
     */
    private String logMsg;

    /**
     * 执行操作
     */
    private String logHandle;

    /**
     * 登录用户
     */
    private String loginUser;

    /**
     * 执行时间
     */
    private Date handleTime;

    /**
     * 日志等级
     */
    private String logLevel;

    public String getLogId() {
        return logId;
    }

    public void setLogId(String logId) {
        this.logId = logId;
    }

    public String getLogArgs() {
        return logArgs;
    }

    public void setLogArgs(String logArgs) {
        this.logArgs = logArgs;
    }

    public String getLogMsg() {
        return logMsg;
    }

    public void setLogMsg(String logMsg) {
        this.logMsg = logMsg;
    }

    public String getLogHandle() {
        return logHandle;
    }

    public void setLogHandle(String logHandle) {
        this.logHandle = logHandle;
    }

    public String getLoginUser() {
        return loginUser;
    }

    public void setLoginUser(String loginUser) {
        this.loginUser = loginUser;
    }

    public Date getHandleTime() {
        return handleTime;
    }

    public void setHandleTime(Date handleTime) {
        this.handleTime = handleTime;
    }

    public String getLogLevel() {
        return logLevel;
    }

    public void setLogLevel(String logLevel) {
        this.logLevel = logLevel;
    }
}

==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/XtLog.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author hqz
 * @version 1.0, 2017/7/10
 * @description 系统日志表
 */
@Table(name = "XT_LOG")
public class XtLog {

    /**
     * 日志编码
     */
    @Id
    private String logId;

    /**
     * 日志参数
     */
    private String logArgs;

    /**
     * 日志信息
     */
    private String logMsg;

    /**
     * 执行操作
     */
    private String logHandle;

    /**
     * 登录用户
     */
    private String loginUser;

    /**
     * 执行时间
     */
    private Date handleTime;

    /**
     * 日志等级
     */
    private String logLevel;

    /**
     * 操作IP
     */
    private String operationIp;


    public String getLogId() {
        return logId;
    }

    public void setLogId(String logId) {
        this.logId = logId;
    }

    public String getLogArgs() {
        return logArgs;
    }

    public void setLogArgs(String logArgs) {
        this.logArgs = logArgs;
    }

    public String getLogMsg() {
        return logMsg;
    }

    public void setLogMsg(String logMsg) {
        this.logMsg = logMsg;
    }

    public String getLogHandle() {
        return logHandle;
    }

    public void setLogHandle(String logHandle) {
        this.logHandle = logHandle;
    }

    public String getLoginUser() {
        return loginUser;
    }

    public void setLoginUser(String loginUser) {
        this.loginUser = loginUser;
    }

    public Date getHandleTime() {
        return handleTime;
    }

    public void setHandleTime(Date handleTime) {
        this.handleTime = handleTime;
    }

    public String getLogLevel() {
        return logLevel;
    }

    public void setLogLevel(String logLevel) {
        this.logLevel = logLevel;
    }

    public String getOperationIp() {
        return operationIp;
    }

    public void setOperationIp(String operationIp) {
        this.operationIp = operationIp;
    }

    @Override
    public String toString() {
        return "XtLog{" +
            "logId='" + logId + '\'' +
            ", logArgs='" + logArgs + '\'' +
            ", logMsg='" + logMsg + '\'' +
            ", logHandle='" + logHandle + '\'' +
            ", loginUser='" + loginUser + '\'' +
            ", handleTime=" + handleTime +
            ", logLevel='" + logLevel + '\'' +
            ", operationIp='" + operationIp + '\'' +
            '}';
    }
}
